@@ -6,10 +6,10 @@ use Graphics::Framebuffer;
 use List::Util qw(min max shuffle);
 use Time::HiRes qw(sleep time);
 
-# use Data::Dumper::Simple; $Data::Dumper::Sortkeys=1;
+ use Data::Dumper::Simple; $Data::Dumper::Sortkeys=1;
 
 system('clear');
-$| = 1;
+$|++;
 
 my $file = 0;
 my $arg = join(' ', @ARGV);
@@ -31,11 +31,25 @@ if ($arg =~ /Y(\d+)/) {
 if ($arg =~ /(\d+)/) {
     $dev = $1;
 }
+my $images_path = (-e 'images/RWBY_White.jpg') ? 'images' : 'examples/images';
 
+print "\n\nGathering images...\n";
+opendir(my $DIR,$images_path);
+chomp(my @files = readdir($DIR));
+closedir($DIR);
+
+our @IMAGES;
+
+foreach my $file (@files) {
+    next if ($file =~ /^\.+/ || $file =~ /Test|gif/);
+    push(@IMAGES,"$images_path/$file");
+}
+
+# print Dumper(\@IMAGES);exit;
 if (defined($new_x)) {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'FILE_MODE' => $file, 'SHOW_ERRORS' => 0, 'SIMULATED_X' => $new_x, 'SIMULATED_Y' => $new_y, 'SPLASH' => 0);
+    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x, 'SIMULATED_Y' => $new_y, 'SPLASH' => 0);
 } else {
-    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'FILE_MODE' => $file, 'SHOW_ERRORS' => 0, 'SPLASH' => 1);
+    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev", 'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SPLASH' => 1);
 }
 
 $SIG{'QUIT'} = sub { $F->clip_reset(); $F->cls('ON'); exec('reset'); };
@@ -53,9 +67,7 @@ my $YY          = $screen_height;
 my $center_x    = $XX / 2;
 my $center_y    = $YY / 2;
 my $factor      = 5;
-my $images_path = (-e 'images/GFB.png') ? 'images' : 'examples/images';
 my $rpi         = ($F->{'fscreeninfo'}->{'id'} =~ /BCM270(8|9)/i) ? 1 : 0;
-
     
 $F->cls('OFF');
 
@@ -77,40 +89,40 @@ polygons(1);
 beziers();
 
 filled_boxes();
-hatch_filled_boxes();
-vertical_gradient_boxes();
-horizontal_gradient_boxes();
-texture_filled_boxes();
-
 filled_rounded_boxes();
-hatch_filled_rounded_boxes();
-vertical_gradient_rounded_boxes();
-horizontal_gradient_rounded_boxes();
-texture_filled_rounded_boxes();
-
 filled_circles();
-hatch_filled_circles();
-vertical_gradient_circles();
-horizontal_gradient_circles();
-texture_filled_circles();
-
-filled_pies();
-hatch_filled_pies();
-vertical_gradient_pies();
-horizontal_gradient_pies();
-texture_filled_pies();
-
 filled_ellipses();
-hatch_filled_ellipses();
-vertical_gradient_ellipses();
-horizontal_gradient_ellipses();
-texture_filled_ellipses();
-
+filled_pies();
 filled_polygons();
+
+hatch_filled_boxes();
+hatch_filled_rounded_boxes();
+hatch_filled_circles();
+hatch_filled_ellipses();
+hatch_filled_pies();
 hatch_filled_polygons();
+
+vertical_gradient_boxes();
+vertical_gradient_rounded_boxes();
+vertical_gradient_circles();
+vertical_gradient_ellipses();
+vertical_gradient_pies();
 vertical_gradient_polygons();
+
+horizontal_gradient_boxes();
+horizontal_gradient_rounded_boxes();
+horizontal_gradient_circles();
+horizontal_gradient_ellipses();
+horizontal_gradient_pies();
 horizontal_gradient_polygons();
+
+texture_filled_boxes();
+texture_filled_rounded_boxes();
+texture_filled_circles();
+texture_filled_ellipses();
+texture_filled_pies();
 texture_filled_polygons();
+
 flood_fill();
 
 truetype_fonts();
@@ -181,8 +193,8 @@ sub color_mapping {
             'y'      => 0,
             'width'  => $XX * .75,
             'height' => ($YY - $F->{'Y_CLIP'}) * .75,
-            'center' => 3,
-            'file'   => "$images_path/testpattern.jpg"
+            'center' => CENTER_XY,
+            'file'   => "$images_path/Test Pattern.jpg"
         }
     );
     $F->blit_write($image);
@@ -361,9 +373,9 @@ sub texture_filled_boxes {
         {
             'x'    => 0,
             'y'    => 0,
-            'width' => $XX,
-            'height' => $YY,
-            'file' => "$images_path/RWBY_Ruby.png"
+#            'width' => $XX,
+#            'height' => $YY,
+            'file' => $IMAGES[int(rand(scalar(@IMAGES)))]
         }
     );
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
@@ -495,9 +507,9 @@ sub texture_filled_rounded_boxes {
         {
             'x'    => 0,
             'y'    => 0,
-            'width' => $XX,
-            'height' => $YY,
-            'file' => "$images_path/RWBY_Ruby.png"
+#            'width' => $XX,
+#            'height' => $YY,
+            'file' => $IMAGES[int(rand(scalar(@IMAGES)))]
         }
     );
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
@@ -615,27 +627,15 @@ sub texture_filled_circles {
     print_it($F, 'Texture Filled Circle Test');
 
     my $image;
-    if ($F->{'BITS'} > 16) {
-        $image = $F->load_image(
-            {
-                'x'    => 0,
-                  'y'    => 0,
-                  'width' => $XX,
-                  'height' => $YY,
-                  'file' => "$images_path/RWBY_Pose.jpg"
-            }
-        );
-    } else {
-        $image = $F->load_image(
-            {
-                'x'    => 0,
-                  'y'    => 0,
-                  'width' => $XX,
-                  'height' => $YY,
-                  'file' => "$images_path/RWBY_Ruby.png"
-            }
-        );
-    }
+    $image = $F->load_image(
+        {
+            'x'    => 0,
+              'y'    => 0,
+#                  'width' => $XX,
+#                  'height' => $YY,
+              'file' => $IMAGES[int(rand(scalar(@IMAGES)))]
+        }
+    );
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
     while (time < $s) {
         $F->circle(
@@ -757,28 +757,17 @@ sub horizontal_gradient_pies {
 
 sub texture_filled_pies {
     print_it($F, 'Texture Filled Pie Test');
+# $F->{'X_CLIP'} = 200;
     my $image;
-    if ($F->{'BITS'} > 16) {
         $image = $F->load_image(
             {
                 'x'    => 0,
                   'y'    => 0,
                   'width' => $XX,
                   'height' => $YY,
-                  'file' => "$images_path/RWBY_Pose.jpg"
+                  'file' => $IMAGES[int(rand(scalar(@IMAGES)))]
             }
         );
-    } else {
-        $image = $F->load_image(
-            {
-                'x'    => 0,
-                  'y'    => 0,
-                  'width' => $XX,
-                  'height' => $YY,
-                  'file' => "$images_path/RWBY_Ruby.png"
-            }
-        );
-    }
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
 
     while (time < $s) {
@@ -898,9 +887,9 @@ sub texture_filled_ellipses {
         {
             'x'    => 0,
             'y'    => 0,
-            'width' => $XX,
-            'height' => $YY,
-            'file' => "$images_path/RWBY_Pose.jpg"
+#            'width' => $XX,
+#            'height' => $YY,
+            'file' => $IMAGES[int(rand(scalar(@IMAGES)))]
         }
     );
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
@@ -1045,9 +1034,9 @@ sub texture_filled_polygons {
         {
             'x'    => 0,
             'y'    => 0,
-            'width' => $XX,
-            'height' => $YY,
-            'file' => "$images_path/RWBY_Pose.jpg"
+#            'width' => $XX,
+#            'height' => $YY,
+            'file' => $IMAGES[int(rand(scalar(@IMAGES)))]
         }
     );
     my $s = ($F->{'BITS'} == 16) ? time + $factor * 2 : time + $factor;
@@ -1151,6 +1140,15 @@ sub rotate_truetype_fonts {
 sub flood_fill {
     print_it($F, 'Testing flood fill');
     $F->clip_reset();
+    my $image = $F->load_image(
+        {
+            'x'    => 0,
+            'y'    => 0,
+#            'width' => $XX,
+#            'height' => $YY,
+            'file' => $IMAGES[int(rand(scalar(@IMAGES)))]
+        }
+    );
     if ($XX > 255) {
         $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
         $F->polygon({ 'coordinates' => [220 * $xm, 190 * $ym, 1520 * $xm, 80 * $xm, 1160 * $xm, $YY, 960 * $xm, 540 * $ym, 760 * $xm, 780 * $ym] });
@@ -1162,7 +1160,8 @@ sub flood_fill {
         $F->circle({ 'x' => 500 * $xm, 'y' => 320 * $ym, 'radius' => 100 * $xm });
         sleep 1 if ($F->{'ACCELERATED'});
         $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
-        $F->fill({ 'x' => 270 * $xm, 'y' => 210 * $ym });
+#        $F->plot({x=>350*$xm,y=>250*$ym,pixel_size=>10});sleep 20;
+        $F->fill({ 'x' => 350 * $xm, 'y' => 250 * $ym ,'texture' => $image});
 
         $F->set_color({ 'red' => rand(256), 'green' => rand(256), 'blue' => rand(256) });
         $F->fill({ 'x' => 960 * $xm, 'y' => 440 * $ym });
@@ -1252,10 +1251,10 @@ sub image_load {
             {
                 'x'      => 0,
                 'y'      => 0,
-                'width'  => int(rand($XX)),
-                'height' => rand($YY - $F->{'Y_CLIP'}),
-                'center' => 3,
-                'file'   => "$images_path/GFB.png"
+#                'width'  => int(rand($XX)),
+#                'height' => rand($YY - $F->{'Y_CLIP'}),
+                'center' => CENTER_XY,
+                'file'   => $IMAGES[int(rand(scalar(@IMAGES)))]
             }
         );
         if (defined($blank)) {
@@ -1272,8 +1271,8 @@ sub image_load {
             'y'      => 0,
             'width'  => $XX,
             'height' => ($YY - $F->{'Y_CLIP'}),
-            'center' => 3,
-            'file'   => "$images_path/GFB.png"
+            'center' => CENTER_XY,
+            'file'   => $IMAGES[int(rand(scalar(@IMAGES)))]
         }
     );
     if (defined($blank)) {
@@ -1294,7 +1293,7 @@ sub blitting {
             'y'      => 0,
             'width'  => min(480, int($XX / 3)),
             'height' => min(510, int($YY / 3)),
-            'file'   => "$images_path/RWBY_Pose.jpg"
+            'file'   => $IMAGES[int(rand(scalar(@IMAGES)))]
         }
     );
     my $s = time + $factor;
@@ -1314,7 +1313,7 @@ sub rotate {
                 'x'     => 0,
                 'y'     => 0,
                 'width' => int($YY * .7),
-                'file'  => "$images_path/RWBY_Oh_No.jpg"
+                'file'  => $IMAGES[int(rand(scalar(@IMAGES)))]
             }
         );
     } elsif ($rpi) {
@@ -1324,7 +1323,7 @@ sub rotate {
                 'y'      => 0,
                 'width'  => 160,
                 'height' => 120,
-                'file'   => "$images_path/RWBY_Oh_No.jpg"
+                'file'   => $IMAGES[int(rand(scalar(@IMAGES)))]
             }
         );
     } else {
@@ -1334,7 +1333,7 @@ sub rotate {
                 'y'      => 0,
                 'width'  => int($XX * .4),
                 'height' => int($YY * .4),
-                'file'   => "$images_path/RWBY_Oh_No.jpg"
+                'file'   => $IMAGES[int(rand(scalar(@IMAGES)))]
             }
         );
     } ## end else [ if ($YY <= 240) ]
@@ -1343,7 +1342,7 @@ sub rotate {
         my $angle = 0;
 
         my $st = 'Counter-Clockwise Rotate Test ';
-        if ($p) {
+        unless ($p) {
             $st .= 'Using Perl algorithm';
         } else {
             $st .= 'Using Imager Library';
@@ -1351,6 +1350,7 @@ sub rotate {
         print_it($F, $st);
         my $s = time + ($factor * 2);
         my $count = 0;
+        $F->acceleration($p);
         while (time < $s || $count < 6) {
             my $rot = $F->blit_transform(
                 {
@@ -1358,7 +1358,6 @@ sub rotate {
                         'degrees' => $angle
                     },
                     'blit_data' => $image,
-                    'perl_only' => $p
                 }
             );
             $rot->{'x'} = abs(($XX - $rot->{'width'}) / 2);
@@ -1373,7 +1372,7 @@ sub rotate {
 
         $angle = 0;
         $st    = 'Clockwise Rotate Test ';
-        if ($p) {
+        unless ($p) {
             $st .= 'Using Perl algorithm';
         } else {
             $st .= 'Using Imager Library';
@@ -1401,10 +1400,11 @@ sub rotate {
             $count++;
         } ## end while (time < $s || $count...)
     } ## end foreach my $p (0 .. 1)
+    $F->acceleration(1);
 } ## end sub rotate
 
 sub flipping {
-    print_it($F, 'Loading "RWBY_Faces.png" For Image Flip Tests', 'FFFF00FF');
+    print_it($F, 'Loading image For Image Flip Tests', 'FFFF00FF');
 
     my $image;
     if ($rpi && $XX > 320) {
@@ -1412,7 +1412,7 @@ sub flipping {
             {
                 'x'    => 0,
                 'y'    => $F->{'Y_CLIP'},
-                'file' => "$images_path/RWBY_Faces.png"
+                'file' => $IMAGES[int(rand(scalar(@IMAGES)))]
             }
         );
     } else {
@@ -1422,7 +1422,7 @@ sub flipping {
                 'y'      => $F->{'Y_CLIP'},
                 'width'  => $XX,
                 'height' => ($YY - $F->{'Y_CLIP'}),
-                'file'   => "$images_path/RWBY_Faces.png"
+                'file'   => $IMAGES[int(rand(scalar(@IMAGES)))]
             }
         );
     } ## end else [ if ($rpi && $XX > 320)]
@@ -1457,7 +1457,7 @@ sub monochrome {
                 'y'      => $F->{'Y_CLIP'},
                 'width'  => int($XX * .6),
                 'height' => int($YY * .6),
-                'file'   => "$images_path/RWBY_Faces.png"
+                'file'   => $IMAGES[int(rand(scalar(@IMAGES)))]
             }
         );
     } else {
@@ -1497,7 +1497,7 @@ sub animated {
                         'width'  => $XX,
                         'height' => $YY - $F->{'Y_CLIP'},
                         'file'   => "$images_path/$info",
-                        'center' => 3
+                        'center' => CENTER_XY
                     }
                 );
             } else {
@@ -1505,7 +1505,7 @@ sub animated {
                 $image = $F->load_image(
                     {
                         'file'   => "$images_path/$info",
-                        'center' => 3
+                        'center' => CENTER_XY
                     }
                 );
             } ## end else [ if ($count || $XX <= 320)]
@@ -1622,8 +1622,8 @@ sub mask_drawing {
             'y'      => $F->{'Y_CLIP'},
             'width'  => ($XX <= 320) ? $XX * .75 : $XX / 2,
             'height' => ($XX <= 320) ? $h * .75 : $h / 2,
-            'file'   => "$images_path/GFB.png",
-            'center' => 3
+            'file'   => $IMAGES[int(rand(scalar(@IMAGES)))],
+            'center' => CENTER_XY
         }
     );
     my $image2 = $F->load_image(
@@ -1632,8 +1632,8 @@ sub mask_drawing {
             'y'            => $F->{'Y_CLIP'},
             'width'        => ($XX <= 320) ? $XX * .75 : $XX / 2,
             'height'       => ($XX <= 320) ? $h * .75 : $h / 2,
-            'file'         => "$images_path/RWBY_beuowolf.jpg",
-            'center'       => 3,
+            'file'         => "$images_path/RWBY Beuowolf.jpg",
+            'center'       => CENTER_XY,
             'convertalpha' => 1
         }
     );
@@ -1646,8 +1646,8 @@ sub mask_drawing {
             'y'      => $F->{'Y_CLIP'},
             'width'  => $XX * .9,
             'height' => $h * .9,
-            'file'   => "$images_path/GFB.png",
-            'center' => 3
+            'file'   => $IMAGES[int(rand(scalar(@IMAGES)))],
+            'center' => CENTER_XY
         }
     );
     $image2 = $F->load_image(
@@ -1656,8 +1656,8 @@ sub mask_drawing {
             'y'            => $F->{'Y_CLIP'},
             'width'        => $XX * .9,
             'height'       => $h * .9,
-            'file'         => "$images_path/RWBY_beuowolf.jpg",
-            'center'       => 3,
+            'file'         => "$images_path/RWBY Beuowolf.jpg",
+            'center'       => CENTER_XY,
             'convertalpha' => 1
         }
     );
@@ -1689,8 +1689,8 @@ sub unmask_drawing {
             'y'            => $F->{'Y_CLIP'},
             'width'        => ($XX <= 320) ? $XX * .75 : $XX / 2,
             'height'       => ($XX <= 320) ? $h * .75 : $h / 2,
-            'file'         => "$images_path/RWBY_beuowolf.jpg",
-            'center'       => 3,
+            'file'         => "$images_path/RWBY Beuowolf.jpg",
+            'center'       => CENTER_XY,
             'convertalpha' => 1
         }
     );
@@ -1700,8 +1700,8 @@ sub unmask_drawing {
             'y'      => $F->{'Y_CLIP'},
             'width'  => ($XX <= 320) ? $XX * .75 : $XX / 2,
             'height' => ($XX <= 320) ? $h * .75 : $h / 2,
-            'file'   => "$images_path/RWBY_Ruby.png",
-            'center' => 3
+            'file'   => $IMAGES[int(rand(scalar(@IMAGES)))],
+            'center' => CENTER_XY
         }
     );
     $F->blit_write($image1);
@@ -1713,8 +1713,8 @@ sub unmask_drawing {
             'y'            => $F->{'Y_CLIP'},
             'width'        => $XX * .9,
             'height'       => $h * .9,
-            'file'         => "$images_path/RWBY_beuowolf.jpg",
-            'center'       => 3,
+            'file'         => "$images_path/RWBY Beuowolf.jpg",
+            'center'       => CENTER_XY,
             'convertalpha' => 1
         }
     );
@@ -1724,8 +1724,8 @@ sub unmask_drawing {
             'y'      => $F->{'Y_CLIP'},
             'width'  => $XX * .9,
             'height' => $h * .9,
-            'file'   => "$images_path/RWBY_Ruby.png",
-            'center' => 3
+            'file'   => $IMAGES[int(rand(scalar(@IMAGES)))],
+            'center' => CENTER_XY
         }
     );
 
@@ -1746,46 +1746,6 @@ sub unmask_drawing {
     } ## end if ($F->{'BITS'} > 16)
 } ## end sub unmask_drawing
 
-sub blit_demo {
-    # This is not finished
-    print_it($F, 'More practical demonstration of blitting');
-    my $image;
-    if ($YY <= 240) {
-        $image = $F->load_image(
-            {
-                'x'      => 0,
-                'y'      => 0,
-                'width'  => int($YY * .7),
-                'file'   => "$images_path/RWBY_Oh_No.jpg",
-                'center' => CENTER_XY
-            }
-        );
-    } elsif ($rpi) {
-        $image = $F->load_image(
-            {
-                'x'      => 0,
-                'y'      => 0,
-                'width'  => 160,
-                'height' => 120,
-                'file'   => "$images_path/RWBY_Oh_No.jpg",
-                'center' => CENTER_XY
-            }
-        );
-    } else {
-        $image = $F->load_image(
-            {
-                'x'      => 0,
-                'y'      => 0,
-                'width'  => int($XX * .4),
-                'height' => int($YY * .4),
-                'file'   => "$images_path/RWBY_Oh_No.jpg",
-                'center' => CENTER_XY
-            }
-        );
-    } ## end else [ if ($YY <= 240) ]
-    sleep $factor;
-}
-
 sub print_it {
     my $fb      = shift;
     my $message = shift;
@@ -1805,7 +1765,7 @@ sub print_it {
                 'color'        => $color,
                 'text'         => $message,
                 'bounding_box' => 1,
-                'center'       => $fb->{'CENTER_X'},
+                'center'       => CENTER_X,
                 'antialias'    => 1
             }
         );
