@@ -8,12 +8,13 @@ use strict;
 
 use Graphics::Framebuffer;
 use Time::HiRes qw(sleep time);
+
 # use Data::Dumper::Simple;$Data::Dumper::Sortkeys=1;
 
-$SIG{'QUIT'} = sub {exec('reset');};
-$SIG{'INT'}  = sub {exec('reset');};
+$SIG{'QUIT'} = sub { exec('reset'); };
+$SIG{'INT'}  = sub { exec('reset'); };
 
-my $args = join('',@ARGV);
+my $args = join('', @ARGV);
 
 my $file = 0;
 $file = 1 if ($args =~ /file/i);
@@ -39,19 +40,20 @@ my %p = (
     'height' => $f->{'YRES'},
     'file'   => $ARGV[-1]
 );
+
 # $p{'noscale'} = 1 if ($ARGV[0] =~ /\.gif$/i);
 my $image = $f->load_image(\%p);
 
 # warn ref($image),"\n\n",Dumper($image->[0]->{'tags'}),"\n\n";exit;
 if (ref($image) eq 'ARRAY') {
-    while(1) {
+    while (1) {
         foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
             my $begin = time;
             $f->blit_write($image->[$frame]);
             my $delay = ($image->[$frame]->{'tags'}->{'gif_delay'} / 100) - (time - $begin);
             sleep $delay if ($delay > 0);
-        }
-    }
+        } ## end foreach my $frame (0 .. (scalar...))
+    } ## end while (1)
 } else {
     $f->blit_write($image);
 }
