@@ -1,8 +1,8 @@
 package Graphics::Framebuffer::Splash;
 
 use strict;
-no strict 'vars'; # We have to map a variable as the screen.  So strict is going to whine about what we do with it.
-no warnings;      # We have to be as quiet as possible
+no strict 'vars';    # We have to map a variable as the screen.  So strict is going to whine about what we do with it.
+no warnings;         # We have to be as quiet as possible
 
 use constant {
     TRUE  => 1,
@@ -14,11 +14,11 @@ use List::Util qw(min max);
 sub _perl_logo {
     my $self = shift;
     return unless (exists($self->{'FONTS'}->{'DejaVuSerif'}));
-    my $hf   = $self->{'H_SCALE'};
-    my $vf   = $self->{'V_SCALE'};
+    my $hf = $self->{'H_SCALE'};
+    my $vf = $self->{'V_SCALE'};
 
     $self->normal_mode();
-    $self->set_color({'red' => 0, 'green' => 0, 'blue' => 0,'alpha'=>128});
+    $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 0, 'alpha' => 128 });
     $self->ellipse(
         {
             'x'       => 965 * $hf,
@@ -28,7 +28,7 @@ sub _perl_logo {
             'filled'  => TRUE
         }
     );
-    $self->set_color({'red' => 0, 'green' => 64, 'blue' => 255,'alpha'=>255});
+    $self->set_color({ 'red' => 0, 'green' => 64, 'blue' => 255, 'alpha' => 255 });
     $self->ellipse(
         {
             'x'       => 960 * $hf,
@@ -57,7 +57,7 @@ sub _perl_logo {
             }
         )
     );
-}
+} ## end sub _perl_logo
 
 sub splash {
     my $self    = shift;
@@ -77,30 +77,31 @@ sub splash {
     $bold =~ s/\.ttf$/Bold.ttf/;
 
     $self->cls();
+    $self->clip_reset();
 
     if (($W <= 320) || ($H <= 240)) {
         $hf = $W / 320;
         $vf = $H / 240;
-        $self->set_color({'red' => 0, 'green' => 0, 'blue' => 64});
+        $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 64 });
         $self->polygon(
             {
                 'coordinates' => [(67.5 * $hf) + $X, (16.875 * $vf) + $Y, (3.325 * $hf) + $X, (178.125 * $vf) + $Y, (267.5 * $hf) + $X, (238.125 * $vf) + $Y, (315 * $hf) + $X, (2.5 * $vf) + $Y],
-                  'filled'      => TRUE,
-                  'gradient'    => {
-                      'start' => {
-                          'red'   => 0,
-                          'green' => 0,
-                          'blue'  => 16
-                      },
-                      'end' => {
-                          'red'   => 0,
-                          'green' => 0,
-                          'blue'  => 200
-                      }
-                  }
+                'filled'      => TRUE,
+                'gradient'    => {
+                    'start' => {
+                        'red'   => 0,
+                        'green' => 0,
+                        'blue'  => 16
+                    },
+                    'end' => {
+                        'red'   => 0,
+                        'green' => 0,
+                        'blue'  => 200
+                    }
+                }
             }
         );
-        $self->set_color({'red' => 0, 'green' => 0, 'blue' => 1});
+        $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 1 });
         $self->rbox(
             {
                 'x'      => (25 * $hf) + $X,
@@ -112,7 +113,7 @@ sub splash {
             }
         );
 
-        $self->set_color({'red' => 128, 'green' => 0, 'blue' => 0});
+        $self->set_color({ 'red' => 128, 'green' => 0, 'blue' => 0 });
         $self->rbox(
             {
                 'x'      => (20 * $hf) + $X,
@@ -123,17 +124,17 @@ sub splash {
                 'filled' => TRUE
             }
         );
-        $self->set_color({'red' => 64, 'green' => 0, 'blue' => 0});
+        $self->set_color({ 'red' => 64, 'green' => 0, 'blue' => 0 });
         $self->circle(
             {
                 'x'      => (37.5 * max($vf, $hf)) + $X,
-                'y'      => (36 * max($vf, $hf)) + $Y,
-                'radius' => 35 * max($vf,  $hf),
+                'y'      => (36 * max($vf,   $hf)) + $Y,
+                'radius' => 35 * max($vf,    $hf),
                 'filled' => TRUE
             }
         );
 
-        $self->set_color({'red' => 255, 'green' => 255, 'blue' => 0});
+        $self->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0 });
         $self->circle(
             {
                 'x'        => (35 * max($hf, $vf)) + $X,
@@ -142,7 +143,7 @@ sub splash {
                 'filled'   => TRUE,
                 'gradient' => {
                     'direction' => 'horizontal',
-                    'start' => {
+                    'start'     => {
                         'red'   => 255,
                         'green' => 0,
                         'blue'  => 0
@@ -157,6 +158,7 @@ sub splash {
         );
         my $color;
         $self->or_mode();
+
         # G
         if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
             $color = '0000FFFF';
@@ -252,21 +254,20 @@ sub splash {
                 }
             )
         );
-        my $gfb = 
-            $self->ttf_print(
-                {
-                    'bounding_box' => TRUE,
-                    'x'            => 0,
-                    'y'            => (100 * $vf) + $Y,
-                    'height'       => 42 * $vf,
-                    'wscale'       => 1,
-                    'color'        => 'FFFF00FF',
-                    'text'         => 'Graphics-Framebuffer',
-                    'bounding_box' => TRUE,
-                    'center'       => $self->{'CENTER_X'},
-                    'antialias'    => FALSE
-                }
-            );
+        my $gfb = $self->ttf_print(
+            {
+                'bounding_box' => TRUE,
+                'x'            => 0,
+                'y'            => (100 * $vf) + $Y,
+                'height'       => 42 * $vf,
+                'wscale'       => 1,
+                'color'        => 'FFFF00FF',
+                'text'         => 'Graphics-Framebuffer',
+                'bounding_box' => TRUE,
+                'center'       => $self->{'CENTER_X'},
+                'antialias'    => FALSE
+            }
+        );
         if ($gfb->{'pwidth'} > int(270 * $hf)) {
             $gfb->{'bounding_box'} = TRUE;
             $gfb->{'wscale'}       = int(270 * $hf) / $gfb->{'pwidth'};
@@ -282,32 +283,31 @@ sub splash {
                     'height'       => 38 * $vf,
                     'wscale'       => 1,
                     'color'        => 'FFFFFFFF',
-                    'text'         => sprintf('VERSION %.02f', $VERSION),
+                    'text'         => sprintf('VERSION %.02f', $version),
                     'bounding_box' => TRUE,
                     'center'       => $self->{'CENTER_X'},
                     'antialias'    => FALSE
                 }
             )
         );
-        my @fonts = grep(!/atari|mono|light|italic|bold|black/i,grep(/condensed/i,(keys %{$self->{'FONTS'}})));
-        my $font  = $fonts[int(rand(scalar(@fonts)))];
-        my $scaleit = 
-          $self->ttf_print(
-              {
-                  'bounding_box' => TRUE,
-                  'x'            => 0,
-                  'y'            => (190 * $vf) + $Y,
-                  'height'       => 48 * $vf,
-                  'wscale'       => 1,
-                  'color'        => 'FFFFFFFF',
-                  'text'         => sprintf('%dx%d-%02d ON %s', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}, uc($self->{'fscreeninfo'}->{'id'} || 'Unknown GPU')),
-                  'bounding_box' => TRUE,
-                  'center'       => $self->{'CENTER_X'},
-                  'antialias'    => FALSE,
-                  'font_path'    => $self->{'FONTS'}->{$font}->{'path'},
-                  'face'         => $self->{'FONTS'}->{$font}->{'font'}
-              }
-          );
+        my @fonts   = grep(!/atari|mono|light|italic|bold|black/i, grep(/condensed/i, (keys %{ $self->{'FONTS'} })));
+        my $font    = $fonts[int(rand(scalar(@fonts)))];
+        my $scaleit = $self->ttf_print(
+            {
+                'bounding_box' => TRUE,
+                'x'            => 0,
+                'y'            => (190 * $vf) + $Y,
+                'height'       => 48 * $vf,
+                'wscale'       => 1,
+                'color'        => 'FFFFFFFF',
+                'text'         => sprintf('%dx%d-%02d ON %s', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}, uc($self->{'fscreeninfo'}->{'id'} || 'Unknown GPU')),
+                'bounding_box' => TRUE,
+                'center'       => $self->{'CENTER_X'},
+                'antialias'    => FALSE,
+                'font_path'    => $self->{'FONTS'}->{$font}->{'path'},
+                'face'         => $self->{'FONTS'}->{$font}->{'font'}
+            }
+        );
         if ($scaleit->{'pwidth'} > int(270 * $hf)) {
             $scaleit->{'bounding_box'} = TRUE;
             $scaleit->{'wscale'}       = int(270 * $hf) / $scaleit->{'pwidth'};
@@ -315,8 +315,9 @@ sub splash {
         }
         $self->ttf_print($scaleit);
     } else {
+
         # Draws the main boxes
-        $self->set_color({'red' => 0, 'green' => 0, 'blue' => 64});
+        $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 64 });
         $self->polygon(
             {
                 'coordinates' => [(400 * $hf) + $X, (80 * $vf) + $Y, (20 * $hf) + $X, (800 * $vf) + $Y, (1600 * $hf) + $X, (1078 * $vf) + $Y, (1900 * $hf) + $X, (5 * $vf) + $Y],
@@ -336,7 +337,7 @@ sub splash {
             }
         );
 
-        $self->set_color({'red' => 0, 'green' => 0, 'blue' => 1});
+        $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 1 });
         $self->rbox(
             {
                 'x'      => (160 * $hf) + $X,
@@ -348,7 +349,7 @@ sub splash {
             }
         );
 
-        $self->set_color({'red' => 128, 'green' => 0, 'blue' => 0});
+        $self->set_color({ 'red' => 128, 'green' => 0, 'blue' => 0 });
         $self->rbox(
             {
                 'x'      => (150 * $hf) + $X,
@@ -361,7 +362,7 @@ sub splash {
         );
 
         # Draws the Circle with GFB in it
-        $self->set_color({'red' => 64, 'green' => 0, 'blue' => 0});
+        $self->set_color({ 'red' => 64, 'green' => 0, 'blue' => 0 });
         $self->circle(
             {
                 'x'      => (207 * $hf) + $X,
@@ -371,7 +372,7 @@ sub splash {
             }
         );
 
-        $self->set_color({'red' => 255, 'green' => 255, 'blue' => 0});
+        $self->set_color({ 'red' => 255, 'green' => 255, 'blue' => 0 });
         $self->circle(
             {
                 'x'        => (200 * $hf) + $X,
@@ -380,7 +381,7 @@ sub splash {
                 'filled'   => TRUE,
                 'gradient' => {
                     'direction' => 'horizontal',
-                    'start' => {
+                    'start'     => {
                         'red'   => 255,
                         'green' => 0,
                         'blue'  => 0
@@ -393,9 +394,9 @@ sub splash {
                 }
             }
         );
-        
+
         # G
-        $self->set_color({'red' => 32, 'green' => 32, 'blue' => 0});
+        $self->set_color({ 'red' => 32, 'green' => 32, 'blue' => 0 });
         $self->filled_pie(
             {
                 'x'             => (102 * $hf) + $X,
@@ -442,17 +443,17 @@ sub splash {
         );
 
         if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $self->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $self->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $self->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $self->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $self->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $self->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
         }
 
         # G
@@ -469,17 +470,17 @@ sub splash {
 
         # F
         if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $self->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $self->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $self->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $self->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $self->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $self->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
         }
         $self->polygon(
             {
@@ -491,17 +492,17 @@ sub splash {
 
         # B
         if ($self->{'COLOR_ORDER'} == $self->{'BGR'}) {
-            $self->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'BRG'}) {
-            $self->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RGB'}) {
-            $self->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'RBG'}) {
-            $self->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
+            $self->set_color({ 'red' => 0, 'green' => 255, 'blue' => 0 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GRB'}) {
-            $self->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
+            $self->set_color({ 'red' => 0, 'green' => 0, 'blue' => 255 });
         } elsif ($self->{'COLOR_ORDER'} == $self->{'GBR'}) {
-            $self->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
+            $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0 });
         }
         $self->polygon(
             {
@@ -526,7 +527,7 @@ sub splash {
                 'filled' => TRUE
             }
         );
-        $self->set_color({'red' => 32, 'green' => 0, 'blue' => 0});
+        $self->set_color({ 'red' => 32, 'green' => 0, 'blue' => 0 });
         $self->rbox(
             {
                 'x'      => (478 * $hf) + $X,
@@ -560,6 +561,7 @@ sub splash {
             }
         );
         $self->or_mode() if ($self->{'BITS'} == 16);
+
         if ($self->{'ACCELERATED'}) {
             $self->ttf_print(
                 $self->ttf_print(
@@ -568,16 +570,16 @@ sub splash {
                         'x'            => (510 * $hf) + $X,
                         'y'            => (300 * $vf) + $Y,
                         'height'       => 110 * $vf,
-                        'wscale'       => 1.8,
+                        'wscale'       => 1.5,
                         'color'        => '00FFFFFF',
-                        'text'         => 'Accelerated',
+                        'text'         => 'Imager Assisted',
                         'bounding_box' => TRUE,
                         'center'       => 0,
                         'antialias'    => ($self->{'BITS'} >= 24) ? TRUE : FALSE
                     }
                 )
             );
-        }
+        } ## end if ($self->{'ACCELERATED'...})
         if ($self->{'BITS'} >= 24) {
             my $shadow = $self->ttf_print(
                 {
@@ -596,49 +598,47 @@ sub splash {
             if ($shadow->{'pwidth'} > (1500 * $hf)) {
                 $shadow->{'bounding_box'} = TRUE;
                 $shadow->{'wscale'}       = int(1500 * $hf) / $shadow->{'pwidth'};
-                $shadow = $self->ttf_print($shadow);
+                $shadow                   = $self->ttf_print($shadow);
             }
             $shadow->{'x'} += max(1, 6 * $hf);
             $shadow->{'y'} += max(1, 6 * $vf);
             delete($shadow->{'center'});
             $self->ttf_print($shadow);
-        }
-        my $gfb =
-          $self->ttf_print(
-              {
-                  'bounding_box' => TRUE,
-                  'x'            => 0,
-                  'y'            => (560 * $vf) + $Y,
-                  'height'       => 200 * $vf,
-                  'wscale'       => 1,
-                  'color'        => 'FFFF00FF',
-                  'text'         => 'Graphics-Framebuffer',
-                  'bounding_box' => TRUE,
-                  'center'       => $self->{'CENTER_X'},
-                  'antialias'    => ($self->{'BITS'} >= 24) ? TRUE : FALSE
-              }
-          );
+        } ## end if ($self->{'BITS'} >=...)
+        my $gfb = $self->ttf_print(
+            {
+                'bounding_box' => TRUE,
+                'x'            => 0,
+                'y'            => (560 * $vf) + $Y,
+                'height'       => 200 * $vf,
+                'wscale'       => 1,
+                'color'        => 'FFFF00FF',
+                'text'         => 'Graphics-Framebuffer',
+                'bounding_box' => TRUE,
+                'center'       => $self->{'CENTER_X'},
+                'antialias'    => ($self->{'BITS'} >= 24) ? TRUE : FALSE
+            }
+        );
         if ($gfb->{'pwidth'} > (1500 * $hf)) {
             $gfb->{'bounding_box'} = TRUE;
             $gfb->{'wscale'}       = int(1500 * $hf) / $gfb->{'pwidth'};
-            $gfb = $self->ttf_print($gfb);
+            $gfb                   = $self->ttf_print($gfb);
         }
         $self->ttf_print($gfb);
 
-        my $rk =
-          $self->ttf_print(
-              {
-                  'bounding_box' => TRUE,
-                  'x'            => 0,
-                  'y'            => (620 * $vf) + $Y,
-                  'height'       => 50 * $vf,
-                  'wscale'       => 1,
-                  'color'        => '00EE00FF',
-                  'text'         => 'by Richard Kelsch',
-                  'bounding_box' => TRUE,
-                  'center'       => FALSE,
-                  'antialias'    => ($self->{'BITS'} >= 24) ? TRUE : FALSE
-              }
+        my $rk = $self->ttf_print(
+            {
+                'bounding_box' => TRUE,
+                'x'            => 0,
+                'y'            => (620 * $vf) + $Y,
+                'height'       => 50 * $vf,
+                'wscale'       => 1,
+                'color'        => '00EE00FF',
+                'text'         => 'by Richard Kelsch',
+                'bounding_box' => TRUE,
+                'center'       => FALSE,
+                'antialias'    => ($self->{'BITS'} >= 24) ? TRUE : FALSE
+            }
         );
         $rk->{'x'} = (1710 * $hf) - $rk->{'pwidth'};
         $self->ttf_print($rk);
@@ -659,21 +659,20 @@ sub splash {
                 }
             )
         );
-        my $scaleit = 
-          $self->ttf_print(
-              {
-                  'bounding_box' => TRUE,
-                  'x'            => 0,
-                  'y'            => (860 * $vf) + $Y,
-                  'height'       => 120 * $vf,
-                  'wscale'       => 1,
-                  'color'        => 'FFFFFFFF',
-                  'text'         => sprintf('%dx%d-%02d on %s', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}, $self->{'fscreeninfo'}->{'id'} || 'Unknown GPU'),
-                  'bounding_box' => TRUE,
-                  'center'       => $self->{'CENTER_X'},
-                  'antialias'    => ($self->{'BITS'} >= 24) ? TRUE : FALSE
-              }
-          );
+        my $scaleit = $self->ttf_print(
+            {
+                'bounding_box' => TRUE,
+                'x'            => 0,
+                'y'            => (860 * $vf) + $Y,
+                'height'       => 120 * $vf,
+                'wscale'       => 1,
+                'color'        => 'FFFFFFFF',
+                'text'         => sprintf('%dx%d-%02d on %s', $self->{'XRES'}, $self->{'YRES'}, $self->{'BITS'}, $self->{'fscreeninfo'}->{'id'} || 'Unknown GPU'),
+                'bounding_box' => TRUE,
+                'center'       => $self->{'CENTER_X'},
+                'antialias' => ($self->{'BITS'} >= 24) ? TRUE : FALSE
+            }
+        );
         if ($scaleit->{'pwidth'} > int(1500 * $hf)) {
             $scaleit->{'bounding_box'} = TRUE;
             $scaleit->{'wscale'}       = int(1500 * $hf) / $scaleit->{'pwidth'};
@@ -681,10 +680,9 @@ sub splash {
         }
         $self->ttf_print($scaleit);
         $self->_perl_logo();
-    }
+    } ## end else [ if (($W <= 320) || ($H...))]
     $self->normal_mode();
-}
-
+} ## end sub splash
 
 1;
 
